@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: FileCopy.h,v 1.51 2002/12/25 13:44:30 lav Exp $ */
+/* $Id: FileCopy.h,v 1.53 2003/11/14 11:30:34 lav Exp $ */
 
 /*
   classes defined here:
@@ -37,6 +37,7 @@
 #include "buffer.h"
 #include "FileAccess.h"
 #include "Speedometer.h"
+#include "Timer.h"
 
 #define FILE_END     (-1L)
 
@@ -134,6 +135,8 @@ public:
 
    void DontStartTransferYet() { start_transfer=false; }
    void StartTransfer() { start_transfer=true; }
+
+   const char *GetDescriptionForLog() { return 0; }
 };
 
 class FileCopy : public SMTask
@@ -301,12 +304,18 @@ public:
    void Fg() { session->SetPriority(1); }
    void Bg() { session->SetPriority(0); }
    void SetFXP(bool on) { fxp=on; }
+
+   const char *GetDescriptionForLog()
+      {
+	 return orig_url ? orig_url : session->GetFileURL(file);
+      }
 };
 
 class FileCopyPeerFDStream : public FileCopyPeer
 {
    FDStream *stream;
    off_t seek_base;
+   Timer *put_ll_timer;
 
    int Get_LL(int size);
    int Put_LL(const char *buf,int size);
@@ -340,6 +349,11 @@ public:
 
    static FileCopyPeerFDStream *NewPut(const char *file,bool cont=false);
    static FileCopyPeerFDStream *NewGet(const char *file);
+
+   const char *GetDescriptionForLog()
+      {
+	 return stream->name;
+      }
 };
 
 class FileCopyPeerDirList : public FileCopyPeer
@@ -375,6 +389,11 @@ public:
    int Do();
    void Fg();
    void Bg();
+
+   const char *GetDescriptionForLog()
+      {
+	 return "[pipe to other job]";
+      }
 };
 
 #endif
