@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: FileCopyFtp.cc,v 1.17 2003/08/21 08:43:23 lav Exp $ */
+/* $Id: FileCopyFtp.cc,v 1.17.2.1 2003/11/26 08:13:26 lav Exp $ */
 
 #include <config.h>
 
@@ -215,7 +215,8 @@ FileCopy *FileCopyFtp::New(FileCopyPeer *s,FileCopyPeer *d,bool c)
    FA *d_s=d->GetSession();
    if(!s_s || !d_s)
       return 0;
-   if(strcmp(s_s->GetProto(),"ftp") || strcmp(d_s->GetProto(),"ftp"))
+   if((strcmp(s_s->GetProto(),"ftp") && strcmp(s_s->GetProto(),"ftps"))
+   || (strcmp(d_s->GetProto(),"ftp") && strcmp(d_s->GetProto(),"ftps")))
       return 0;
    if(!ResMgr::QueryBool("ftp:use-fxp",s_s->GetHostName())
    || !ResMgr::QueryBool("ftp:use-fxp",d_s->GetHostName()))
