@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: FileSet.h,v 1.25 2001/12/14 18:13:02 lav Exp $ */
+/* $Id: FileSet.h,v 1.27 2003/01/27 15:52:46 lav Exp $ */
 
 #ifndef FILESET_H
 #define FILESET_H
@@ -108,7 +108,7 @@ class PatternSet;
 class FileSet
 {
 public:
-   enum sort_e { BYNAME, BYSIZE, DIRSFIRST, BYRANK };
+   enum sort_e { BYNAME, BYSIZE, DIRSFIRST, BYRANK, BYDATE };
 
 private:
    FileInfo **files;
@@ -142,6 +142,7 @@ public:
    void	 SubtractSame(const FileSet *,int ignore);
    void	 SubtractAny(const FileSet *);
    void  SubtractOlderThan(time_t t);
+   void  SubtractDirs();
    void  SubtractNotIn(const FileSet *);
    void  SubtractCurr();
    void  Sort(sort_e newsort, bool casefold=false);
