@@ -1,7 +1,7 @@
 /*
  * lftp and utils
  *
- * Copyright (c) 1996-1997 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2002 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -48,6 +48,7 @@ FDStream::FDStream(int new_fd,const char *new_name)
       name=0;
    error_text=0;
    status=0;
+   close_fd=false;
 }
 FDStream::FDStream()
 {
@@ -55,6 +56,7 @@ FDStream::FDStream()
    name=0;
    error_text=0;
    status=0;
+   close_fd=false;
 }
 void FDStream::MakeErrorText()
 {
@@ -66,7 +68,8 @@ void FDStream::MakeErrorText()
 }
 FDStream::~FDStream()
 {
-   // don't close fd
+   if(close_fd)
+      close(fd);
    xfree(name);
    xfree(error_text);
 };
@@ -97,8 +100,7 @@ void OutputFilter::Child(int *p)
 	 dup2(second_fd,1);
 	 close(second_fd);
       }
-      int fl;
-      fcntl(1,F_GETFL,&fl);
+      int fl=fcntl(1,F_GETFL);
       fcntl(1,F_SETFL,fl&~O_NONBLOCK);
    }
 }
@@ -117,8 +119,7 @@ void InputFilter::Child(int *p)
 	 dup2(second_fd,0);
 	 close(second_fd);
       }
-      int fl;
-      fcntl(0,F_GETFL,&fl);
+      int fl=fcntl(0,F_GETFL);
       fcntl(0,F_SETFL,fl&~O_NONBLOCK);
    }
 }
@@ -402,6 +403,12 @@ off_t FileStream::get_size()
 #include "SMTask.h"
 bool FDStream::NonFatalError(int err)
 {
+   if(err==EDQUOT || err==ENOSPC)
+   {
+      struct stat st;
+      if(fd>=0 && fstat(fd,&st)!=-1 && st.st_nlink==0)
+	 return false;
+   }
    bool non_fatal=SMTask::NonFatalError(err);
    if(non_fatal)
       set_status(strerror(err));
