@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: FindJob.cc,v 1.27 2001/12/21 17:11:58 lav Exp $ */
+/* $Id: FindJob.cc,v 1.31 2002/12/18 06:37:08 lav Exp $ */
 
 #include <config.h>
 #include <assert.h>
@@ -361,9 +361,9 @@ void FinderJob::ShowRunStatus(StatusLine *sl)
    }
 }
 
-void FinderJob::PrintStatus(int v)
+void FinderJob::PrintStatus(int v,const char *prefix)
 {
-   SessionJob::PrintStatus(v);
+   SessionJob::PrintStatus(v,prefix);
 
    char *path=0;
    switch(state)
@@ -436,6 +436,7 @@ FinderJob_List::FinderJob_List(FileAccess *s,ArgV *a,FDStream *o)
 FinderJob_List::~FinderJob_List()
 {
    Delete(buf);
+   delete args;
 }
 
 void FinderJob_List::Finish()
