@@ -1,7 +1,7 @@
 /*
  * lftp and utils
  *
- * Copyright (c) 2001 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 2001-2002 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -96,10 +96,19 @@ GetFileInfo::GetFileInfo(FileAccess *a, const char *_dir, bool _showdir)
    li=0;
    from_cache=0;
    saved_error_text=0;
-   was_directory=0;
+   was_directory=false;
    prepend_path=true;
 
    origdir=xstrdup(session->GetCwd());
+
+   const char *bn=basename_ptr(dir);
+   if(bn[0]=='.' && (bn[1]==0 || bn[1]=='/' ||
+                     (bn[1]=='.' && (bn[2]==0 || bn[2]=='/')))
+   || bn[0]=='/')
+   {
+      // . .. / are directories, don't try them as a file.
+      tried_file=true;
+   }
 }
 
 GetFileInfo::~GetFileInfo()
@@ -281,6 +290,10 @@ int GetFileInfo::Do()
 
 	 result = new FileSet;
 	 result->Add(fi);
+
+	 xfree(path_to_prefix);
+	 path_to_prefix=dirname_alloc(dir);
+
 	 state=DONE;
 	 return MOVED;
       }
@@ -456,7 +469,7 @@ done:
    case DONE:
       if(!done)
       {
-	 if(result && showdir && result->get_fnum())
+	 if(result && showdir && result->get_fnum()>0)
 	 {
 	    FileInfo *f = (*result)[0];
 	    /* Make sure the filename is what was requested (ie ".."). */
