@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: GetJob.h,v 1.6 2001/12/17 14:59:04 lav Exp $ */
+/* $Id: GetJob.h,v 1.8 2003/06/26 10:12:59 lav Exp $ */
 
 #ifndef GETJOB_H
 #define GETJOB_H
@@ -39,8 +39,9 @@ protected:
 
    void RemoveBackupFile();
 
-   FileCopyPeer *NoProtoSrc(const char *src);
-   FileCopyPeer *NoProtoDst(const char *dst);
+   FileCopyPeer *NoProtoSrc(const char *src,bool from_local);
+   FileCopyPeer *NoProtoDst(const char *dst,bool to_local);
+   FileCopyPeer *CreateCopyPeer(const char *path,FA::open_mode mode);
 
 public:
    GetJob(FileAccess *s,ArgV *a,bool c=false);
