@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: Http.cc,v 1.160 2003/06/21 08:40:06 lav Exp $ */
+/* $Id: Http.cc,v 1.160.2.1 2003/12/11 08:49:47 lav Exp $ */
 
 #include <config.h>
 #include "trio.h"
@@ -814,6 +814,11 @@ int Http::Do()
    case DISCONNECTED:
       if(mode==CLOSED || !hostname)
 	 return m;
+      if(mode==STORE && pos>0 && entity_size>=0 && pos>=entity_size)
+      {
+	 state=DONE;
+	 return MOVED;
+      }
       if(!hftp && mode==QUOTE_CMD && !post)
       {
       handle_quote_cmd:
@@ -1017,6 +1022,11 @@ int Http::Do()
 	 SetError(NOT_SUPP);
 	 return MOVED;
       }
+      if(mode==STORE && pos>0 && entity_size>=0 && pos>=entity_size)
+      {
+	 state=DONE;
+	 return MOVED;
+      }
       DebugPrint("---- ",_("Sending request..."));
       if(mode==ARRAY_INFO)
       {
@@ -1628,7 +1638,8 @@ int Http::SendEOT()
    {
       if(state==RECEIVING_HEADER && send_buf->Size()==0)
       {
-	 shutdown(sock,1);
+	 if(entity_size==NO_SIZE)
+	    shutdown(sock,1);
 	 sent_eot=true;
       	 return(OK);
       }
