@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: MirrorJob.cc,v 1.99 2003/04/30 12:26:32 lav Exp $ */
+/* $Id: MirrorJob.cc,v 1.99.2.1 2003/12/01 07:47:08 lav Exp $ */
 
 #include <config.h>
 
@@ -1282,7 +1282,8 @@ CMD(mirror)
 	    }
 	    target_dir=alloca_strdup(target_url.path);
 	 }
-	 if(target_dir[0] && target_dir[strlen(target_dir)-1]=='/')
+	 if(target_dir[0] && target_dir[strlen(target_dir)-1]=='/'
+	 && basename_ptr(target_dir)[0]!='/')
 	 {
 	    // user wants source dir name appended.
 	    const char *base=basename_ptr(source_dir);
