@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: ProcWait.cc,v 1.14 2002/03/18 16:29:28 lav Exp $ */
+/* $Id: ProcWait.cc,v 1.15 2002/07/17 15:10:18 lav Exp $ */
 
 #include <config.h>
 #include <sys/wait.h>
@@ -83,6 +83,8 @@ bool ProcWait::handle_info(int info)
    }
    else
    {
+      if(WIFSIGNALED(info) && WTERMSIG(info)==SIGINT)
+	 SignalHook::IncreaseCount(SIGINT);
       status=TERMINATED;
       term_info=info;
       return true;
