@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: Resolver.cc,v 1.57 2002/06/03 08:50:27 lav Exp $ */
+/* $Id: Resolver.cc,v 1.58.2.1 2003/12/11 08:49:48 lav Exp $ */
 
 #include <config.h>
 
@@ -49,6 +49,9 @@
 #include "log.h"
 #include "plural.h"
 
+#ifndef C_IN
+# define C_IN 1
+#endif
 #ifndef T_SRV
 # define T_SRV 33
 #endif
@@ -746,6 +749,7 @@ void Resolver::LookupOne(const char *name)
 #  ifndef HAVE_H_ERRNO
 #   define HAVE_H_ERRNO 1
 #  endif
+#  undef h_errno // it could be a macro, but we want it to be local variable.
       int h_errno=0;
       ha=getipnodebyname(name,af,0,&h_errno);
 # elif defined(HAVE_GETHOSTBYNAME2)
