@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: SleepJob.h,v 1.6 2002/01/04 12:31:30 lav Exp $ */
+/* $Id: SleepJob.h,v 1.7 2002/07/31 11:28:01 lav Exp $ */
 
 #ifndef SLEEPJOB_H
 #define SLEEPJOB_H
@@ -48,7 +48,7 @@ public:
    SleepJob(const TimeInterval &when,FileAccess *s=0,LocalDirectory *cwd=0,char *what=0);
    ~SleepJob();
 
-   void PrintStatus(int v);
+   void PrintStatus(int v,const char *);
 
    void Repeat() { repeat=true; start_time-=next_time.Seconds(); }
 
