@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: buffer.h,v 1.25 2003/06/21 08:40:08 lav Exp $ */
+/* $Id: buffer.h,v 1.27.2.1 2003/11/26 08:13:29 lav Exp $ */
 
 #ifndef BUFFER_H
 #define BUFFER_H
@@ -89,6 +89,24 @@ public:
    void vFormat(const char *f, va_list v);
    void PutEOF() { eof=true; PutEOF_LL(); }
 
+   unsigned long long UnpackUINT64BE(int offset=0);
+   unsigned UnpackUINT32BE(int offset=0);
+   unsigned UnpackUINT16BE(int offset=0);
+   unsigned UnpackUINT8(int offset=0);
+   void PackUINT64BE(unsigned long long data);
+   void PackUINT32BE(unsigned data);
+   void PackUINT16BE(unsigned data);
+   void PackUINT8(unsigned data);
+
+   long long UnpackINT64BE(int offset=0);
+   int UnpackINT32BE(int offset=0);
+   int UnpackINT16BE(int offset=0);
+   int UnpackINT8(int offset=0);
+   void PackINT64BE(long long data);
+   void PackINT32BE(int data);
+   void PackINT16BE(int data);
+   void PackINT8(int data);
+
    // useful for cache.
    void Save(int m) { save=true; save_max=m; }
    bool IsSaving() const { return save; }
@@ -106,6 +124,7 @@ public:
    virtual FgData *GetFgData(bool) { return 0; }
 
    virtual time_t EventTime() { return now; }
+   virtual const char *Status() { return ""; }
 
    Buffer();
 };
@@ -154,6 +173,7 @@ public:
    int Do();
    bool Done();
    FgData *GetFgData(bool fg);
+   const char *Status() { return stream->status; }
 };
 
 class FileAccess;
@@ -173,6 +193,7 @@ public:
 
    void Suspend();
    void Resume();
+   const char *Status();
 };
 
 #endif // BUFFER_H
